@@ -1,9 +1,8 @@
 name = "ipregistry"
 
-from .version import __version__
-
 from .cache import *
 from .core import *
+from .json import *
 from .model import *
 from .request import *
 from .util import *
