@@ -14,9 +14,10 @@
     limitations under the License.
 """
 
-class UserAgent:
+
+class UserAgents:
 
     @staticmethod
-    def isBot(header):
+    def is_bot(header):
         header = header.lower()
         return "bot" in header or "spider" in header
